program MenuButton;

{---------------------------------------------------------------------
Example application for the custom control MenuButton (MButton.DLL) of
the SMWCC 1.0 Custom Control Pack

Copyright (C) by Sebastian Modersohn
---------------------------------------------------------------------}

{$R MBAPP}

uses WinTypes, WinProcs, OWindows, ODialogs, Strings, BWCC,
     {the import unit for the button}
     MButton, MButtonC;

{for loading the DLL}
const DLLName        ='MBUTTONS.DLL';
      em_DLLNotFound =1;

type
  PMButtonWindow = ^TMButtonWindow;
  TMButtonWindow = object(TDlgWindow)
    MB: PMButton;
    constructor Init(AParent: PWindowsObject; AName: PChar);

    procedure SetupWindow; virtual;

    procedure WMCommand(var Msg: TMessage);
      virtual wm_first + wm_Command;

    procedure Help(var Msg: TMessage);
      virtual id_First + idHelp;
    procedure Ok(var Msg: TMessage);
      virtual id_First + id_OK;
  end;

{App that loads and frees the DLL and initializes the main window}
  PMButtonApp = ^TMButtonApp;
  TMButtonApp = object(TApplication)
    Lib: THandle;
    constructor Init(AName: PChar);
    destructor Done; virtual;
    procedure InitMainWindow; virtual;
    procedure Error(ErrorCode: Integer); virtual;
  end;

{ TMButtonWindow }

constructor TMButtonWindow.Init(AParent: PWindowsObject; AName: PChar);
begin
  inherited Init(AParent, AName);
  {Inits the Button}
  MB:=New(PMButton, InitResource(@Self, 300));
  {the button is normally disposed by the destructor of the parent}
end;

procedure TMButtonWindow.SetupWindow;
begin
  inherited SetupWindow;
  {configure the menu}
  MB^.AppendItem(100, 'Test&1');
  MB^.AppendItem(101, 'Test&2');
  MB^.AppendSeparator;
  MB^.AppendItem(102, 'Test&3');
  MB^.AppendItem(103, 'Test&4');

  {starts a new row with that item}
  MB^.AppendItemAndRow(104, 'Test&5');
  MB^.AppendItem(105, 'Test&6');
  MB^.AppendSeparator;
  MB^.AppendItem(106, 'Test&7');
  MB^.AppendItem(107, 'Test&8');
end;

procedure TMButtonWindow.WMCommand(var Msg: TMessage);
begin
  {If it is it a menu message change buttons text}
  if Msg.lParamHi=0 then
  begin
    case Msg.wParam of
      100: SetWindowText(MB^.HWindow, 'Test&1');
      101: SetWindowText(MB^.HWindow, 'Test&2');
      102: SetWindowText(MB^.HWindow, 'Test&3');
      103: SetWindowText(MB^.HWindow, 'Test&4');
      104: SetWindowText(MB^.HWindow, 'Test&5');
      105: SetWindowText(MB^.HWindow, 'Test&6');
      106: SetWindowText(MB^.HWindow, 'Test&7');
      107: SetWindowText(MB^.HWindow, 'Test&8');
    end;
  end;
  inherited WMCommand(Msg);
end;

procedure TMButtonWindow.Help(var Msg: TMessage);
begin
  WinHelp(HWindow, HelpFile, Help_Context, 300);
end;

procedure TMButtonWindow.Ok(var Msg: TMessage);
begin
  CloseWindow;
end;

{ TMButtonApp }

constructor TMButtonApp.Init(AName: PChar);
begin
  {Load the library}
  Lib := LoadLibrary(DLLName);
  {If it wasn't loaded succesfully, then call error with em_DLLNotFound}
  if Lib < 32 then
    Status := em_DLLNotFound
  else
    inherited Init(AName);
end;

destructor TMButtonApp.Done;
begin
  inherited Done;
  {Free the library}
  FreeLibrary(Lib);
end;

procedure TMButtonApp.InitMainWindow;
begin
  MainWindow := New(PMButtonWindow, Init(nil, 'dlg_main'));
end;

procedure TMButtonApp.Error(ErrorCode: Integer);
begin
  case ErrorCode of
    em_DLLNotFound:
      begin
        {if the dll could not be loaded display the message and fail the app}
        MessageBox(0, DLLName + ' not found. Please make sure that Windows will found this file!', 'Hard error',
          mb_Ok or mb_IconStop);
        Halt(ErrorCode);
      end;
  else
    inherited Error(ErrorCode);
  end;
end;

var
  App: TMButtonApp;

begin
  App.Init('MButton Demo');
  App.Run;
  App.Done;
end.
